#include <osgSim/Version>

const char* osgSimGetVersion()
{
    return "1.1";
}


const char* osgSimGetLibraryName()
{
    return "OpenSceneGraph Visual Simulation Library";
}
